pub struct RetryManager { /* private fields */ }Expand description
Retry manager for executing operations with automatic retry
Implementations
Sourceimpl RetryManager
impl RetryManager
Sourcepub fn new(policy: RetryPolicy) -> Self
pub fn new(policy: RetryPolicy) -> Self
Create a new retry manager with the given policy
Sourcepub fn for_streaming() -> Self
pub fn for_streaming() -> Self
Create a retry manager for streaming operations
Sourcepub fn with_retry_callback(self, callback: RetryCallback) -> Self
pub fn with_retry_callback(self, callback: RetryCallback) -> Self
Set a callback to be notified on retry attempts